@@ -22,44 +22,38 @@ NULL
 #' @aliases intersecting_units,Raster,Raster-method intersecting_units,Raster,Spatial-method intersecting_units,Spatial,Raster-method intersecting_units,Spatial,Spatial-method intersecting_units,sf,Spatial-method intersecting_units,Spatial,sf-method intersecting_units,sf,sf-method intersecting_units,Raster,sf-method intersecting_units,sf,Raster-method intersecting_units,data.frame,ANY-method
 #'
 #' @examples
+#' \dontrun{
 #' # create data
-#' r <- raster(matrix(1:9, byrow = TRUE, ncol=3))
+#' r <- raster(matrix(1:9, byrow = TRUE, ncol = 3))
 #' r_with_holes <- r
 #' r_with_holes[c(1, 5, 9)] <- NA
 #' ply <- rasterToPolygons(r)
-#' ply_with_holes <- st_as_sf(rasterToPolygons(r_with_holes))
+#' ply_with_holes <- sf::st_as_sf(rasterToPolygons(r_with_holes))
 #'
 #' # intersect raster with raster
-#' \dontrun{
 #' par(mfrow = c(1, 2))
 #' plot(r, main = "x=Raster")
 #' plot(r_with_holes, main = "y=Raster")
-#' }
 #' print(intersecting_units(r, r_with_holes))
 #'
 #' # intersect raster with polygons (sf)
-#' \dontrun{
 #' par(mfrow = c(1, 2))
 #' plot(r, main = "x=Raster")
 #' plot(ply_with_holes, main = "y=sf", key.pos = NULL, reset = FALSE)
-#' }
 #' print(intersecting_units(r, ply_with_holes))
 #'
 #' # intersect polygons (Spatial) with raster
-#' \dontrun{
 #' par(mfrow = c(1, 2))
 #' plot(ply, main = "x=Spatial")
 #' plot(r_with_holes, main = "y=Raster")
-#' }
 #' print(intersecting_units(ply, r_with_holes))
 #'
 #' # intersect polygons (Spatial) with polygons (sf)
-#' \dontrun{
 #' par(mfrow = c(1, 2))
 #' plot(ply, main = "x=Spatial")
 #' plot(ply_with_holes, main = "y=sf", key.pos = NULL, reset = FALSE)
-#' }
 #' print(intersecting_units(ply, ply_with_holes))
+#' }
 #'
 #' @export
 methods::setGeneric("intersecting_units",
@@ -168,7 +162,7 @@ methods::setMethod(
                                  dims = c(nrow(y), nrow(x)))
     # exclude units from being intersecting if they only touch
     int1[int2 > 0.5] <- 0
-    int1 <- methods::as(Matrix::drop0(int1), "dgTMatrix")
+    int1 <- as_Matrix(Matrix::drop0(int1), "dgTMatrix")
     int1@j + 1
   }
 )
@@ -186,7 +180,7 @@ methods::setMethod(
       isTRUE(raster::nlayers(x) == 1),
       sf::st_crs(x@crs) == sf::st_crs(y),
       intersecting_extents(x, y))
-    intersecting_units(x = x,  y = fasterize::fasterize(y, x, field = NULL))
+    intersecting_units(x = x, y = fasterize::fasterize(y, x, field = NULL))
   }
 )
 
