@@ -6,7 +6,7 @@ NULL
 #' Create a systematic conservation planning problem. This function is used to
 #' specify the basic data used in a spatial prioritization problem: the
 #' spatial distribution of the planning units and their costs, as well as
-#' the features (e.g. species, ecosystems) that need to be conserved. After
+#' the features (e.g., species, ecosystems) that need to be conserved. After
 #' constructing this `ConservationProblem-class` object, it can be
 #' customized to meet specific goals using [objectives],
 #' [targets], [constraints], and
@@ -29,7 +29,7 @@ NULL
 #'   cells to `NA`, or use the `add_locked_out_constraint` function.
 #'
 #' @param features The feature data can be specified in a variety of ways.
-#'   The specific formats that can be used depend on the cost data format (i.e.
+#'   The specific formats that can be used depend on the cost data format (i.e.,
 #'   argument to `x`) and whether the problem should have a single zone or
 #'   multiple zones. If the problem should have a single zone, then the feature
 #'   data can be specified following:
@@ -38,7 +38,7 @@ NULL
 #'     [`x = sf::st_sf()`][sf::st_sf()]:
 #'     [`y = Raster-class`][raster::Raster-class]
 #'     object showing the distribution of conservation features. Missing
-#'     values (i.e. `NA` values) can be used to indicate the absence of
+#'     values (i.e., `NA` values) can be used to indicate the absence of
 #'     a feature in a particular cell instead of explicitly setting these
 #'     cells to zero. Note that this argument type for `features` can
 #'     only be used to specify data for problems involving a single zone.
@@ -77,7 +77,7 @@ NULL
 #'     [`x = sf::st_sf()`][sf::st_sf()]:
 #'     [`y = ZonesRaster`][zones()]:
 #'     object showing the distribution of conservation features in multiple
-#'     zones. As above, missing values (i.e. `NA` values) can be used to
+#'     zones. As above, missing values (i.e., `NA` values) can be used to
 #'     indicate the absence of a feature in a particular cell instead of
 #'     explicitly setting these cells to zero.
 #'   * [`x = Spatial-class`][sp::Spatial-class], or
@@ -159,34 +159,34 @@ NULL
 #' on the management action(s), you can compile the following data.
 #'
 #' First, you will need to create a set of planning units
-#' (i.e. discrete spatial areas) to inform decision making.
+#' (i.e., discrete spatial areas) to inform decision making.
 #' Planning units are often created by subdividing a study region
 #' into a set square or hexagonal cells. They can also be created using
-#' administrative boundaries (e.g. provinces), land management boundaries
-#' (e.g. property boundaries derived from cadastral data), or
-#' ecological boundaries (e.g. based on ecosystem classification data).
-#' The size (i.e. spatial grain) of the planning units is often determined
+#' administrative boundaries (e.g., provinces), land management boundaries
+#' (e.g., property boundaries derived from cadastral data), or
+#' ecological boundaries (e.g., based on ecosystem classification data).
+#' The size (i.e., spatial grain) of the planning units is often determined
 #' based on a compromise between the scale needed to inform decision making, the
 #' spatial accuracy (resolution) of available datasets, and
 #' the computational resources available for generating prioritizations
-#' (e.g. RAM and number of CPUs on your computer).
+#' (e.g., RAM and number of CPUs on your computer).
 #'
 #' Second, you will need data to quantify the cost of implementing
 #' implementing each management action within each planning unit.
 #' Critically, the cost data should reflect the management action(s)
 #' considered in the exercise.
 #' For example, costs are often specified using data that reflect economic
-#' expenditure (e.g. land acquisition cost),
-#' socioeconomic conditions (e.g. human population density),
+#' expenditure (e.g., land acquisition cost),
+#' socioeconomic conditions (e.g., human population density),
 #' opportunity costs of foregone commercial activities
-#' (e.g. logging or agriculture), or
+#' (e.g., logging or agriculture), or
 #' opportunity costs of foregone recreational activities
-#' (e.g. recreational fishing) activities,
+#' (e.g., recreational fishing) activities,
 #' In some cases -- depending on the management action(s) considered --
 #' it can make sense to use a constant cost value
-#' (e.g. all planning units are assigned a cost value equal to one)
+#' (e.g., all planning units are assigned a cost value equal to one)
 #' or use a cost value based on spatial extent
-#' (e.g. each planning unit is assigned a cost value based on its total area).
+#' (e.g., each planning unit is assigned a cost value based on its total area).
 #' Also, in most cases, you want to avoid negative cost values.
 #' This because a negative value means that a place is *desirable*
 #' for implementing a management action, and such places will almost
@@ -197,13 +197,13 @@ NULL
 #' To achieve this, you will need to select a set of conservation features
 #' that relate to the over-arching goals of the exercise.
 #' For example, conservation features often include
-#' species (e.g. Clouded Leopard), habitats (e.g. mangroves or
+#' species (e.g., Clouded Leopard), habitats (e.g., mangroves or
 #' cloud forest), or ecosystems.
 #' The benefit that each feature derives from a planning unit
-#' can take a variety of forms, but is typically occupancy (i.e.
+#' can take a variety of forms, but is typically occupancy (i.e.,
 #' presence or absence), area of occurrence within each planning unit
-#' (e.g. based on species' geographic range data), or
-#' a measure of habitat suitability (e.g. estimated using a statistical model).
+#' (e.g., based on species' geographic range data), or
+#' a measure of habitat suitability (e.g., estimated using a statistical model).
 #' After compiling these data, you have the minimal data need to generate
 #' a prioritization.
 #'
@@ -256,7 +256,7 @@ NULL
 #' formulated as mixed integer linear programming problem, you can use
 #' the [write_problem()] function to save the optimization problem
 #' to a plain-text file on your computer and then view it using a standard
-#' text editor (e.g. Notepad).
+#' text editor (e.g., Notepad).
 #'
 #' Please note that this function internally computes the amount of each
 #' feature in each planning unit when this data is not supplied (using the
@@ -322,13 +322,13 @@ NULL
 #'       add_default_solver(verbose = FALSE)
 #'
 #' # since geo-processing can be slow for large spatial vector datasets
-#' # (e.g. polygons, lines, points), it can be worthwhile to pre-process the
+#' # (e.g., polygons, lines, points), it can be worthwhile to pre-process the
 #' # planning unit data so that it contains columns indicating the amount of
 #' # each feature inside each planning unit
-#' # (i.e. each column corresponds to a different feature)
+#' # (i.e., each column corresponds to a different feature)
 #'
 #' # calculate the amount of each species within each planning unit
-#' # (i.e. SpatialPolygonsDataFrame object)
+#' # (i.e., SpatialPolygonsDataFrame object)
 #' pre_proc_data <- rij_matrix(sim_pu_polygons, sim_features)
 #'
 #' # add extra columns to the polygon (Spatial) planning unit data
@@ -361,7 +361,7 @@ NULL
 #'
 #' # in addition to spatially explicit data, pre-processed aspatial data
 #' # can also be used to create a problem
-#' # (e.g. data created using external spreadsheet software)
+#' # (e.g., data created using external spreadsheet software)
 #' costs <- sim_pu_polygons$cost
 #' features <- data.frame(id = seq_len(nlayers(sim_features)),
 #'                        name = names(sim_features))
@@ -396,8 +396,9 @@ NULL
 #' points(s4[s4$solution_1 > 0.5, ], col = "darkgreen", cex = 2, pch = 19)
 #'
 #' # note that as_Spatial() is for convenience to plot all solutions together
-#' plot(as_Spatial(s5), main = "sf (polygon) data", pch = 19)
-#' plot(as_Spatial(s5[s5$solution_1 > 0.5, ]), col = "darkgreen", add = TRUE)
+#' plot(sf::as_Spatial(s5), main = "sf (polygon) data", pch = 19)
+#' plot(sf::as_Spatial(s5[s5$solution_1 > 0.5, ]),
+#'      col = "darkgreen", add = TRUE)
 #'
 #' plot(s6, main = "preprocessed data (polygon data)", pch = 19)
 #' plot(s6[s6$solution_1 > 0.5, ], col = "darkgreen", add = TRUE)
@@ -939,12 +940,13 @@ methods::setMethod(
     # convert rij matrices to sparse format if needed
     pos <- which(rowSums(!is.na(x)) > 0)
     rij <- lapply(rij_matrix, function(z) {
-      if (!inherits(z, "dgCMatrix")) {
+      if (inherits(z, "dgCMatrix")) {
+        z@x[which(is.na(z@x))] <- 0
+      } else {
         z[which(is.na(z))] <- 0
-        rownames(z) <- as.character(features$name)
-        z <- methods::as(z[, pos, drop = FALSE], "dgCMatrix")
       }
-      return(z)
+      rownames(z) <- as.character(features$name)
+      Matrix::drop0(methods::as(z[, pos, drop = FALSE], "dgCMatrix"))
     })
     names(rij) <- names(rij_matrix)
     # create new problem object
@@ -1062,7 +1064,7 @@ methods::setMethod(
     assertthat::assert_that(
       all(!geometry_classes(x) %in% c("GEOMETRYCOLLECTION", "MULTIPOINT")),
       msg = paste("argument to x contains invalid geometry types",
-                  "(i.e. GEOMETRYCOLLECTION or MULTIPOINT)"))
+                  "(i.e., GEOMETRYCOLLECTION or MULTIPOINT)"))
     x2 <- sf::st_drop_geometry(x)
     assertthat::assert_that(
       all(unlist(as.list(features), recursive = TRUE, use.names = FALSE) %in%
