@@ -4,8 +4,7 @@ test_that("Waiver", {
   # constructor
   i <- new_waiver()
   # methods
-  i
-  print(i)
+  invisible(suppressMessages(i))
   expect_true(inherits(i, "Waiver"))
   expect_true(is.Waiver(i))
 })
