@@ -54,7 +54,7 @@ test_that("proportion decisions (floating point)", {
   skip_if_not_installed("prioritizrdata")
   # make data
   data(tas_pu, tas_features, package = "prioritizrdata")
-  tas_pu <- tas_pu[1:10, ]
+  tas_pu <- tas_pu[seq_len(15), ]
   p <- problem(tas_pu, tas_features, cost = "cost") %>%
        add_min_set_objective() %>%
        add_relative_targets(1) %>%
@@ -224,3 +224,29 @@ test_that("start_solution", {
   expect_equal(raster::values(s1), raster::values(s2))
   expect_equal(raster::values(s1), raster::values(s3))
 })
+
+test_that("correct solution (last rij value = 0)", {
+  skip_on_cran()
+  skip_if_not_installed("rcbc")
+  # create data
+  cost <- raster::raster(matrix(c(1000, 100, 200, 300, 1), nrow = 1))
+  features <- raster::stack(
+    raster::raster(matrix(c(5,  5,   0,  0,  0), nrow = 1)),
+    raster::raster(matrix(c(2,  0,   8,  10, 0), nrow = 1)),
+    raster::raster(matrix(c(10, 100, 10, 10, 0), nrow = 1)))
+  # create problem
+  p <- problem(cost, features) %>%
+       add_min_set_objective() %>%
+       add_manual_targets(
+         tibble::tibble(
+           feature = names(features),
+           type = "absolute",
+           sense = c("=", ">=", "<="),
+           target = c(5, 10, 20))) %>%
+       add_cbc_solver(gap = 0, verbose = FALSE)
+  # solve problem
+  s1 <- solve(p)
+  s2 <- solve(p)
+  # test for correct solution
+  expect_equal(raster::values(s1), c(1, 0, 1, 0, 0))
+  expect_equal(raster::values(s1), raster::values(s2))})
