@@ -21,7 +21,7 @@ test_that("minimum set objective (compile, single zone)", {
   # i,j,x matrix for planning unit boundaries
   Matrix::diag(c_data) <- 0
   c_data <- Matrix::drop0(c_data)
-  c_data <- as(c_data, "dgTMatrix")
+  c_data <- as_Matrix(Matrix::tril(c_data), "dgTMatrix")
   # objectives for boundary decision variables
   c_obj <- o$obj()[n_pu + seq_len(length(c_data@i))]
   # lower bound for boundary decision variables
@@ -50,13 +50,13 @@ test_that("minimum set objective (compile, single zone)", {
   expect_equal(c_sense, rep(c("<=", "<="), length(c_data@i)))
   expect_equal(c_rhs, rep(c(0, 0), length(c_data@i)))
   counter <- n_f
-  for (i in seq_along(length(c_data@i))) {
+  for (i in seq_along(c_data@i)) {
     counter <- counter + 1
-    expect_true(o$A()[counter, n_pu + i] == 1)
-    expect_true(o$A()[counter, c_data@i[i] + 1] == -1)
+    expect_equal(o$A()[counter, n_pu + i], 1)
+    expect_equal(o$A()[counter, c_data@i[i] + 1], -1)
     counter <- counter + 1
-    expect_true(o$A()[counter, n_pu + i] == 1)
-    expect_true(o$A()[counter, c_data@j[i] + 1] == -1)
+    expect_equal(o$A()[counter, n_pu + i], 1)
+    expect_equal(o$A()[counter, c_data@j[i] + 1], -1)
   }
 })
 
@@ -112,6 +112,10 @@ test_that("invalid inputs (single zone)", {
   expect_error(add_connectivity_penalties(p, 1, 0, data = c_data))
   expect_error(add_connectivity_penalties(p, 5, data = c_data[, -1]))
   expect_error(add_connectivity_penalties(p, 5, data = c_data[-1, ]))
+  ac_data <- matrix(
+    runif(raster::ncell(sim_pu_raster) ^ 2),
+    ncol = raster::ncell(sim_pu_raster))
+  expect_error(add_connectivity_penalties(p, 5, data = ac_data))
 })
 
 test_that("minimum set objective (compile, multiple zones)", {
@@ -135,14 +139,17 @@ test_that("minimum set objective (compile, multiple zones)", {
   n_z <- p$number_of_zones()
   # prepare matrix
   c_data <- cm * -100
+  c_data <- as_Matrix(Matrix::tril(c_data), "dgTMatrix")
   c_weights <- rep(Matrix::diag(c_data), n_z) * rep(diag(zm), each = n_pu)
   Matrix::diag(c_data) <- 0
   c_data <- Matrix::drop0(c_data)
-  c_data <- as(c_data, "dgTMatrix")
+  c_data <- as_Matrix(c_data, "dgTMatrix")
   c_penalties <- c()
-  for (i in seq_len(n_z))
-    for (j in seq_len(n_z))
-      c_penalties <- c(c_penalties, c_data@x *zm[i, j])
+  for (i in seq_len(n_z)) {
+    for (j in seq_len(n_z)) {
+      c_penalties <- c(c_penalties, c_data@x * zm[i, j])
+    }
+  }
   # objectives for connectivity decision variables
   c_obj <- o$obj()[(n_pu * n_z) + seq_len(length(c_data@i) * n_z * n_z)]
   # lower bound for connectivity decision variables
@@ -181,11 +188,11 @@ test_that("minimum set objective (compile, multiple zones)", {
       for (k in seq_along(c_data@i)) {
         counter <- counter + 1
         counter2 <- counter2 + 1
-        expect_true(o$A()[counter, (n_pu * n_z) + counter2] == 1)
-        expect_true(o$A()[counter, ((i - 1) * n_pu) + c_data@i[k] + 1] == -1)
+        expect_equal(o$A()[counter, (n_pu * n_z) + counter2], 1)
+        expect_equal(o$A()[counter, ((i - 1) * n_pu) + c_data@i[k] + 1], -1)
         counter <- counter + 1
-        expect_true(o$A()[counter, (n_pu * n_z) + counter2] == 1)
-        expect_true(o$A()[counter, ((j - 1) * n_pu) + c_data@j[k] + 1] == -1)
+        expect_equal(o$A()[counter, (n_pu * n_z) + counter2], 1)
+        expect_equal(o$A()[counter, ((j - 1) * n_pu) + c_data@j[k] + 1], -1)
       }
     }
   }
@@ -304,8 +311,8 @@ test_that("invalid inputs (multiple zones)", {
         add_relative_targets(matrix(0.1, nrow = 5, ncol = 3)) %>%
         add_binary_decisions()
   # tests
-  expect_error(add_connectivity_penalties(p, NA_real_, zm ,cm))
-  expect_error(add_connectivity_penalties(p, Inf, zm ,cm))
+  expect_error(add_connectivity_penalties(p, NA_real_, zm, cm))
+  expect_error(add_connectivity_penalties(p, Inf, zm,cm))
   expect_error(add_connectivity_penalties(p, 1, zm[-1, ], cm))
   expect_error(add_connectivity_penalties(p, 1, zm[, -1], cm))
   expect_error(add_connectivity_penalties(p, 1, `[<-`(zm, 1, -2), cm))
@@ -327,7 +334,7 @@ test_that("alternative data formats", {
   data(sim_pu_raster, sim_features)
   # create connectivity matrices
   m <- adjacency_matrix(sim_pu_raster)
-  m2 <- as(m, "dgTMatrix")
+  m2 <- as_Matrix(m, "dgTMatrix")
   m2 <- data.frame(id1 = m2@i + 1, id2 = m2@j + 1, boundary = m2@x)
   # create problem
   p0 <- problem(sim_pu_raster, sim_features) %>%
