@@ -44,7 +44,9 @@ test_that("minimum set objective (matrix, compile, single zone)", {
     p1 %>%
     add_linear_penalties(
       3,
-      as(matrix(raster::values(sim_features[[1]]) * 8, ncol = 1), "dgCMatrix"))
+      as_Matrix(
+        matrix(raster::values(sim_features[[1]]) * 8, ncol = 1),
+        "dgCMatrix"))
   o1 <- compile(p1)
   o2 <- compile(p2)
   o3 <- compile(p3)
