@@ -18,6 +18,32 @@ test_that("data.frame", {
   expect_equal(y, c(1, 2, 0, NA))
 })
 
+test_that("Spatial", {
+  # create data
+  data(sim_pu_polygons)
+  x <- sim_pu_polygons[seq_len(4), ]
+  x$V1 <- c(1, 0, 0, NA)
+  x$V2 <- c(0, 1, 0, NA)
+  x$V3 <- c(0, 0, 0, NA)
+  # create category vector
+  y <- category_vector(x[, c("V1", "V2", "V3")])
+  # run tests
+  expect_equal(y, c(1, 2, 0, NA))
+})
+
+test_that("sf", {
+  # create data
+  data(sim_pu_sf)
+  x <- sim_pu_sf[seq_len(4), ]
+  x$V1 <- c(1, 0, 0, NA)
+  x$V2 <- c(0, 1, 0, NA)
+  x$V3 <- c(0, 0, 0, NA)
+  # create category vector
+  y <- category_vector(x[, c("V1", "V2", "V3")])
+  # run tests
+  expect_equal(y, c(1, 2, 0, NA))
+})
+
 test_that("invalid inputs", {
   expect_error(category_vector(data.frame(integer(0), integer(0))))
   expect_error(category_vector(data.frame(a = 1, b = 2)))
